*************************************
The sherpa.optmethods.optscipy module
*************************************

.. currentmodule:: sherpa.optmethods.optscipy

.. automodule:: sherpa.optmethods.optscipy

  .. rubric:: Classes
              
  .. autosummary::
     :toctree: api

     Scipy_Minimize
     Scipy_Basinhopping
     Scipy_DifferentialEvolution
     Scipy_DualAnnealing
     Scipy_Shgo
     Scipy_Direct

Class Inheritance Diagram
=========================

.. inheritance-diagram::  Scipy_Minimize Scipy_Basinhopping Scipy_DifferentialEvolution Scipy_DualAnnealing Scipy_Shgo Scipy_Direct
   :parts: 1